@@ -1,9 +1,4 @@
 .onLoad <- function(lib, pkg){
-    require("methods", character = TRUE, quietly = TRUE) 
-    require("distr", character = TRUE, quietly = TRUE) 
-    require("distrEx", character = TRUE, quietly = TRUE) 
-    require("RandVar", character = TRUE, quietly = TRUE) 
-    require("ROptEstOld", character = TRUE, quietly = TRUE) 
 }
 
 # Regression type families
